Struct ffmpeg_sidecar::event::AVStream
source · pub struct AVStream {
pub stream_type: String,
pub format: String,
pub pix_fmt: String,
pub width: u32,
pub height: u32,
pub fps: f32,
pub parent_index: usize,
pub raw_log_message: String,
}Fields
stream_type: StringTypically video or audio, but might be something else like data or subtitle.
format: StringCorresponds to stream -f parameter, e.g. rawvideo, h264, or mpegts
pix_fmt: StringCorresponds to stream -pix_fmt parameter, e.g. rgb24
width: u32Width in pixels
height: u32Height in pixels
fps: f32Framerate in frames per second
parent_index: usizeThe index of the input or output that this stream belongs to
raw_log_message: StringThe stderr line that this stream was parsed from