Struct ffmpeg_sidecar::event::FfmpegProgress
source · pub struct FfmpegProgress {
pub frame: u32,
pub fps: f32,
pub q: f32,
pub size_kb: u32,
pub time: String,
pub bitrate_kbps: f32,
pub speed: f32,
pub raw_log_message: String,
}Fields
frame: u32index of the current output frame
fps: f32frames per second
q: f32Quality factor (if applicable)
size_kb: u32Current total size of the output in kilobytes
time: StringThe raw time string in a format like 00:03:29.04
bitrate_kbps: f32Bitrate in kilobits per second
speed: f32Processing speed as a ratio of the input duration
- 1x is realtime
- 2x means 2 seconds of input are processed in 1 second of wall clock time
raw_log_message: StringThe line that this progress was parsed from