Struct ffmpeg_sidecar::event::OutputVideoFrame
source · pub struct OutputVideoFrame {
pub width: u32,
pub height: u32,
pub pix_fmt: String,
pub output_index: u32,
pub data: Vec<u8>,
pub frame_num: u32,
pub timestamp: f32,
}Fields
width: u32The width of this video frame in pixels
height: u32The height of this video frame in pixels
pix_fmt: StringThe pixel format of the video frame, corresponding to the chosen
-pix_fmt FFmpeg parameter.
output_index: u32The index of the FFmpeg output stream that emitted this frame. In a typical case, there is only one output stream and this will be 0.
data: Vec<u8>Raw image frame data. The layout of the pixels in memory depends on
width, height, and pix_fmt.
frame_num: u32Index of current frame, starting at 0 and monotonically increasing by 1
timestamp: f32Output frame timestamp in seconds