FfmpegTimeDuration

Struct FfmpegTimeDuration 

pub struct FfmpegTimeDuration(/* private fields */);
A FfmpegTimeDuration type to represent a ffmpeg time duration described in FFmpeg documentation

This type wraps an i64 internally, representing time in microseconds, similar to how FFmpeg handles time durations internally.

Conversions

The From trait implementations for numeric types (such as f64, f32, i64, etc.) convert between FfmpegTimeDuration and numeric values in seconds:

  • Converting from a numeric type to FfmpegTimeDuration interprets the numeric value as seconds
  • Converting from FfmpegTimeDuration to a numeric type returns the duration in seconds
  • Adding or subtracting with numeric values adds or subtracts seconds

Traits

FfmpegTimeDuration implement many common traits, including Add, Sub. It implements Default by returning a zero-length FfmpegTimeDuration.

Examples

use ffmpeg_sidecar::ffmpeg_time_duration::FfmpegTimeDuration;
use ffmpeg_sidecar::command::FfmpegCommand;

let second = FfmpegTimeDuration::from_str("00:00:01").unwrap();
let hundred_milliseconds = FfmpegTimeDuration::from_str("100ms").unwrap();

assert_eq!(second.as_seconds(), 1.0);
assert_eq!(hundred_milliseconds.as_seconds(), 0.1);

FfmpegCommand::new()
   .arg("-ss")
   .arg(second.to_string());

Implementations

Source

impl FfmpegTimeDuration

pub fn new(microseconds: i64) -> Self

pub fn as_micros(&self) -> i64

pub fn from_micros(microseconds: i64) -> Self

pub fn as_seconds(self) -> f64

pub fn from_seconds(seconds: f64) -> Self

pub fn from_str(str: &str) -> Option<Self>

pub fn as_duration(&self) -> Duration

pub fn from_duration(duration: Duration) -> Self

pub fn to_alt_string(&self) -> String

Returns a string representation of the duration in microseconds with “us” suffix.